@@ -1,4 +1,6 @@
-"""A module for compatibility with the docutils>=0.17 `include` directive, in RST documents::
+"""A module for compatibility with the docutils>=0.17 `include` directive, in RST documents:
+
+For example::
 
    .. include:: path/to/file.md
       :parser: myst_parser.docutils_
