@@ -357,9 +357,7 @@ class DocutilsRenderer(RendererProtocol):
             if temp_root_node is not None:
                 # we need to temporarily set the root node,
                 # and we also want to restore the level_to_section mapping at the end
-                current_level_to_section = {
-                    i: node for i, node in self._level_to_section.items()
-                }
+                current_level_to_section = dict(self._level_to_section.items())
                 current_root_node = self.md_env.get("temp_root_node", None)
                 self.md_env["temp_root_node"] = temp_root_node
             yield
@@ -1856,11 +1854,12 @@ class DocutilsRenderer(RendererProtocol):
                 variable_context
             )
         except Exception as error:
-            error_msg = self.reporter.error(
+            self.create_warning(
                 f"Substitution error:{error.__class__.__name__}: {error}",
+                MystWarnings.SUBSTITUTION,
                 line=position,
+                append_to=self.current_node,
             )
-            self.current_node += [error_msg]
             return
 
         # handle circular references
@@ -1871,11 +1870,12 @@ class DocutilsRenderer(RendererProtocol):
         self.document.sub_references = getattr(self.document, "sub_references", set())
         cyclic = references.intersection(self.document.sub_references)
         if cyclic:
-            error_msg = self.reporter.error(
+            self.create_warning(
                 f"circular substitution reference: {cyclic}",
+                MystWarnings.SUBSTITUTION,
                 line=position,
+                append_to=self.current_node,
             )
-            self.current_node += [error_msg]
             return
 
         # TODO improve error reporting;
@@ -1974,7 +1974,7 @@ def default_slugify(title: str) -> str:
     - https://github.com/jch/html-pipeline/blob/master/lib/html/pipeline/toc_filter.rb
     - https://gist.github.com/asabaylus/3071099
     """
-    return _SLUGIFY_CLEAN_REGEX.sub("", title.strip().lower().replace(" ", "-"))
+    return _SLUGIFY_CLEAN_REGEX.sub("", title.lower().replace(" ", "-"))
 
 
 def compute_unique_slug(
