@@ -8,8 +8,7 @@ from typing import Callable
 from markdown_it import MarkdownIt
 from markdown_it.renderer import RendererProtocol
 from mdit_py_plugins.amsmath import amsmath_plugin
-from mdit_py_plugins.anchors import anchors_plugin
-from mdit_py_plugins.attrs import attrs_plugin
+from mdit_py_plugins.attrs import attrs_block_plugin, attrs_plugin
 from mdit_py_plugins.colon_fence import colon_fence_plugin
 from mdit_py_plugins.deflist import deflist_plugin
 from mdit_py_plugins.dollarmath import dollarmath_plugin
@@ -48,7 +47,7 @@ def create_md_parser(
             # note, strikethrough currently only supported tentatively for HTML
             .enable("strikethrough")
             .enable("table")
-            .use(tasklists_plugin)
+            .use(tasklists_plugin, enabled=config.enable_checkboxes)
             .enable("linkify")
             .use(wordcount_plugin, per_minute=config.words_per_minute)
         )
@@ -98,17 +97,21 @@ def create_md_parser(
     if "fieldlist" in config.enable_extensions:
         md.use(fieldlist_plugin)
     if "tasklist" in config.enable_extensions:
-        md.use(tasklists_plugin)
+        md.use(tasklists_plugin, enabled=config.enable_checkboxes)
     if "substitution" in config.enable_extensions:
         md.use(substitution_plugin, *config.sub_delimiters)
-    if "attrs_image" in config.enable_extensions:
-        md.use(attrs_plugin, after=("image",))
-    if config.heading_anchors is not None:
+    if "attrs_inline" in config.enable_extensions:
         md.use(
-            anchors_plugin,
-            max_level=config.heading_anchors,
-            slug_func=config.heading_slug_func,
+            attrs_plugin,
+            after=("image", "code_inline", "link_close", "span_close"),
+            spans=True,
+            span_after="footnote_ref",
         )
+    elif "attrs_image" in config.enable_extensions:
+        # TODO deprecate
+        md.use(attrs_plugin, after=("image",))
+    if "attrs_block" in config.enable_extensions:
+        md.use(attrs_block_plugin)
     for name in config.disable_syntax:
         md.disable(name, True)
 
